//=============================================================================
// LHUDKeypadWindow. Made by Alpha ~ http://www.dxalpha.co.uk
//=============================================================================
class LHUDKeypadWindow extends HUDKeypadWindow;

var LController keypadOwnerL;

var bool bValidated;

event InitWindow()
{
  Super.InitWindow();
  bValidated = False;

  SetWindowAlignments(HALIGN_Center, VALIGN_Center);
  SetSize(103, 162);
  SetMouseFocusMode(MFocus_EnterLeave);

  inputCode="";

  // Create the buttons
  CreateKeypadButtons();
  CreateInputTextWindow();

  bTickEnabled = True;

  StyleChanged();
}

event DestroyWindow()
{
  Super.DestroyWindow();

  keypadOwnerL._keypadWindow = None;
  keypadOwnerL.Deactivate();
}

function InitData()
{
  GenerateKeypadDisplay();

  winText.SetTextColor(colHeaderText);
  winText.SetText(msgEnterCode);
}

function Tick(float deltaTime)
{
  if (!bFirstFrameDone)
  {
    SetCursorPos(width, height);
    bFirstFrameDone = True;
  }
}

event DrawWindow(GC gc)
{
  DrawBackground(gc);
  DrawBorder(gc);

  Super.DrawWindow(gc);
}

function DrawBackground(GC gc)
{
  if (bBackgroundTranslucent)
    gc.SetStyle(DSTY_Translucent);
  else
    gc.SetStyle(DSTY_Masked);
  
  gc.SetTileColor(colBackground);

  gc.DrawTexture(0, 0, width, height, 0, 0, texBackground);
}

function DrawBorder(GC gc)
{
  if (bDrawBorder)
  {
    if (bBorderTranslucent)
      gc.SetStyle(DSTY_Translucent);
    else
      gc.SetStyle(DSTY_Masked);
    
    gc.SetTileColor(colBorder);

    gc.DrawTexture(0, 0, width, height, 0, 0, texBorder);
  }
}

function CreateKeypadButtons()
{
  local int i, x, y;

  for (y=0; y<4; y++)
  {
    for (x=0; x<3; x++)
    {
      i = x + y * 3;
      btnKeys[i] = HUDKeypadButton(NewChild(Class'HUDKeypadButton'));
      btnKeys[i].SetPos((x * 26) + 16, (y * 28) + 35);
      btnKeys[i].num = i;
    }
  }
}

function CreateInputTextWindow()
{
  winText = TextWindow(NewChild(Class'TextWindow'));
  winText.SetPos(17, 21);
  winText.SetSize(75, 11);
  winText.SetTextMargins(0, 0);
  winText.SetTextAlignments(HALIGN_Center, VALIGN_Center);
  winText.SetFont(Font'FontMenuSmall');
  winText.SetTextColor(colHeaderText);
  winText.SetText(msgEnterCode);
}

function bool ButtonActivated( Window buttonPressed )
{
  local bool bHandled;
  local int i;

  bHandled = False;

  for (i=0; i<12; i++)
  {
    if (buttonPressed == btnKeys[i])
    {
      PressButton(i);
      bHandled = True;
      break;
    }
  }

  if (!bHandled)
    bHandled = Super.ButtonActivated(buttonPressed);

  return bHandled;
}

event bool VirtualKeyPressed(EInputKey key, bool bRepeat)
{
  local bool bKeyHandled;

  bKeyHandled = True;

  if (IsKeyDown(IK_Alt) || IsKeyDown(IK_Ctrl))
    return False;

  if (!bRepeat)
  {
    switch(key) 
    {  
      case IK_0:
      case IK_NUMPAD0:  btnKeys[10].PressButton(); break;
      case IK_1:
      case IK_NUMPAD1:  btnKeys[0].PressButton(); break;
      case IK_2:
      case IK_NUMPAD2:  btnKeys[1].PressButton(); break;
      case IK_3:
      case IK_NUMPAD3:  btnKeys[2].PressButton(); break;
      case IK_4:
      case IK_NUMPAD4:  btnKeys[3].PressButton(); break;
      case IK_5:
      case IK_NUMPAD5:  btnKeys[4].PressButton(); break;
      case IK_6:
      case IK_NUMPAD6:  btnKeys[5].PressButton(); break;
      case IK_7:
      case IK_NUMPAD7:  btnKeys[6].PressButton(); break;
      case IK_8:
      case IK_NUMPAD8:  btnKeys[7].PressButton(); break;
      case IK_9:
      case IK_NUMPAD9:  btnKeys[8].PressButton(); break;

      default:
        bKeyHandled = False;
    }
  }

  if (!bKeyHandled)
    return Super.VirtualKeyPressed(key, bRepeat);
  else
    return bKeyHandled;
}

function PressButton(int num)
{
  local sound tone;

  if (bWait)
    return;

  if (Len(inputCode) < 16)
  {
    inputCode = inputCode $ IndexToString(num);
    switch (num)
    {
      case 0:    tone = sound'Touchtone1'; break;
      case 1:    tone = sound'Touchtone2'; break;
      case 2:    tone = sound'Touchtone3'; break;
      case 3:    tone = sound'Touchtone4'; break;
      case 4:    tone = sound'Touchtone5'; break;
      case 5:    tone = sound'Touchtone6'; break;
      case 6:    tone = sound'Touchtone7'; break;
      case 7:    tone = sound'Touchtone8'; break;
      case 8:    tone = sound'Touchtone9'; break;
      case 9:    tone = sound'Touchtone10'; break;
      case 10:  tone = sound'Touchtone0'; break;
      case 11:  tone = sound'Touchtone11'; break;
    }

    player.PlaySound(tone, SLOT_None);
  }

  GenerateKeypadDisplay();
  winText.SetTextColor(colHeaderText);
  winText.SetText(msgEnterCode);

  if (Len(inputCode) == keypadOwnerL.passLength)
    ValidateCode();
}

function ValidateCode()
{
  if(keypadOwnerL == None)
    return;

  keypadOwnerL._validateCode(inputCode);
}

function setStatus(int newStatus)
{
  if(newStatus == 1)
  {
    bValidated = True;
    player.PlaySound(keypadOwnerL.successSound, SLOT_None);
    winText.SetTextColor(colGreen);
    winText.SetText(msgAccessGranted);
  }
  else
  {
    bValidated = False;
    player.PlaySound(keypadOwnerL.failureSound, SLOT_None);
    winText.SetTextColor(colRed);
    winText.SetText(msgAccessDenied);
  }
  bWait = True;
  AddTimer(1.0, False, 0, 'KeypadDelay');
}

function KeypadDelay(int timerID, int invocations, int clientData)
{
  bWait = False;

  if(bValidated)
    root.PopWindow();
  else
  {
    inputCode = "";
    GenerateKeypadDisplay();
    winText.SetTextColor(colHeaderText);
    winText.SetText(msgEnterCode);
  }
}

function string IndexToString(int num)
{
  local string str;

  // buttons 0-8 are ok as is (text 1-9)
  // button 9 is *
  // button 10 is 0
  // button 11 is #
  switch (num)
  {
    case 9:    str = "*"; break;
    case 10:  str = "0"; break;
    case 11:  str = "#"; break;
    default:  str = String(num+1); break;
  }

  return str;
}

function GenerateKeypadDisplay()
{
  local int i;

  msgEnterCode = "";

  for (i = 0; i < keypadOwnerL.passLength; i++)
  {
    if (i == Len(inputCode))
      msgEnterCode = msgEnterCode $ "|p5";
    msgEnterCode = msgEnterCode $ "~";
  }
}

event StyleChanged()
{
  local ColorTheme theme;

  theme = player.ThemeManager.GetCurrentHUDColorTheme();

  colBackground = theme.GetColorFromName('HUDColor_Background');
  colBorder     = theme.GetColorFromName('HUDColor_Borders');
  colHeaderText = theme.GetColorFromName('HUDColor_HeaderText');

  bBorderTranslucent     = player.GetHUDBorderTranslucency();
  bBackgroundTranslucent = player.GetHUDBackgroundTranslucency();
  bDrawBorder            = player.GetHUDBordersVisible();
}


defaultproperties
{
  texBackground=Texture'DeusExUI.UserInterface.HUDKeypadBackground'
  texBorder=Texture'DeusExUI.UserInterface.HUDKeypadBorder'
  msgAccessDenied="~~DENIED~~"
  msgAccessGranted="~~GRANTED~~"
}
